@@ -12,11 +12,6 @@ from io import BytesIO, SEEK_END
 from typing import Union, Optional, AnyStr, IO, List, Dict
 from zipfile import ZipFile
 
-from azure.storage.blob import BlobServiceClient
-
-from azure.kusto.data.exceptions import KustoBlobError
-from azure.kusto.ingest._resource_manager import _ResourceUri
-
 OptionalUUID = Optional[Union[str, uuid.UUID]]
 
 
@@ -142,46 +137,18 @@ class BlobDescriptor(DescriptorBase):
         :type path: str.
         :param size: estimated size of file if known.
         :type size: Optional[int].
-        :param source_id: a v4 uuid to serve as the sources id.
+        :param source_id: a v4 uuid to serve as the source's id.
         :type source_id: OptionalUUID
         """
         self.path: str = path
         self.size: Optional[int] = size
         self.source_id: uuid.UUID = ensure_uuid(source_id)
 
-    @staticmethod
-    def upload_from_different_descriptor(
-        containers: List[_ResourceUri],
-        descriptor: Union[FileDescriptor, "StreamDescriptor"],
-        database: str,
-        table: str,
-        stream: IO[AnyStr],
-        proxy_dict: Optional[Dict[str, str]],
-        timeout: int,
-    ) -> "BlobDescriptor":
-        """
-        Uploads and transforms FileDescriptor or StreamDescriptor into a BlobDescriptor instance
-        :param List[_ResourceUri] containers: blob containers
-        :param Union[FileDescriptor, "StreamDescriptor"] descriptor:
-        :param string database: database to be ingested to
-        :param string table: table to be ingested to
-        :param IO[AnyStr] stream: stream to be ingested from
-        :param Optional[Dict[str, str]] proxy_dict: proxy urls
-        :param int timeout: Azure service call timeout in seconds
-        :return new BlobDescriptor instance
-        """
-        blob_name = "{db}__{table}__{guid}__{file}".format(db=database, table=table, guid=descriptor.source_id, file=descriptor.stream_name)
-        random_container = random.choice(containers)
-        try:
-            blob_service = BlobServiceClient(random_container.account_uri, proxies=proxy_dict)
-            blob_client = blob_service.get_blob_client(container=random_container.object_name, blob=blob_name)
-            blob_client.upload_blob(data=stream, timeout=timeout)
-        except Exception as e:
-            raise KustoBlobError(e)
-        return BlobDescriptor(blob_client.url, descriptor.size, descriptor.source_id)
-
     def get_tracing_attributes(self) -> dict:
-        return {self._BLOB_URI: self.path, self._SOURCE_ID: str(self.source_id)}
+        # Remove query parameters from self.path, if exists
+        if self.path:
+            obfuscated_path = self.path.split("?")[0].split(";")[0]
+        return {self._BLOB_URI: obfuscated_path, self._SOURCE_ID: str(self.source_id)}
 
 
 class StreamDescriptor(DescriptorBase):
@@ -214,13 +181,13 @@ class StreamDescriptor(DescriptorBase):
     def compress_stream(self) -> None:
         stream = self.stream
         zipped_stream = BytesIO()
-        buffer = stream.read()
+        stream_buffer = stream.read()
         with GzipFile(filename="data", fileobj=zipped_stream, mode="wb") as f_out:
-            if isinstance(buffer, str):
-                data = bytes(buffer, "utf-8")
+            if isinstance(stream_buffer, str):
+                data = bytes(stream_buffer, "utf-8")
                 f_out.write(data)
             else:
-                f_out.write(buffer)
+                f_out.write(stream_buffer)
         zipped_stream.seek(0)
         self.is_compressed = True
         self.stream_name += ".gz"
