@@ -1,10 +1,14 @@
 # Copyright (c) Microsoft Corporation.
 # Licensed under the MIT License
 from typing import Union, AnyStr, Optional
-
 from typing import IO
 
+from azure.core.tracing.decorator import distributed_trace
+from azure.core.tracing import SpanKind
+
 from azure.kusto.data import KustoClient, KustoConnectionStringBuilder, ClientRequestProperties
+
+from ._ingest_telemetry import IngestTracingAttributes
 from .base_ingest_client import BaseIngestClient, IngestionResult, IngestionStatus
 from .descriptors import FileDescriptor, StreamDescriptor
 from .ingestion_properties import IngestionProperties
@@ -32,11 +36,15 @@ class KustoStreamingIngestClient(BaseIngestClient):
     def set_proxy(self, proxy_url: str):
         self._kusto_client.set_proxy(proxy_url)
 
+    @distributed_trace(kind=SpanKind.CLIENT)
     def ingest_from_file(self, file_descriptor: Union[FileDescriptor, str], ingestion_properties: IngestionProperties) -> IngestionResult:
         """Ingest from local files.
         :param file_descriptor: a FileDescriptor to be ingested.
         :param azure.kusto.ingest.IngestionProperties ingestion_properties: Ingestion properties.
         """
+        file_descriptor = FileDescriptor.get_instance(file_descriptor)
+        IngestTracingAttributes.set_ingest_descriptor_attributes(file_descriptor, ingestion_properties)
+
         super().ingest_from_file(file_descriptor, ingestion_properties)
 
         stream_descriptor = StreamDescriptor.from_file_descriptor(file_descriptor)
@@ -44,12 +52,16 @@ class KustoStreamingIngestClient(BaseIngestClient):
         with stream_descriptor.stream:
             return self.ingest_from_stream(stream_descriptor, ingestion_properties)
 
+    @distributed_trace(kind=SpanKind.CLIENT)
     def ingest_from_stream(self, stream_descriptor: Union[StreamDescriptor, IO[AnyStr]], ingestion_properties: IngestionProperties) -> IngestionResult:
         """Ingest from io streams.
         :param azure.kusto.ingest.StreamDescriptor stream_descriptor: An object that contains a description of the stream to
                be ingested.
         :param azure.kusto.ingest.IngestionProperties ingestion_properties: Ingestion properties.
         """
+        stream_descriptor = StreamDescriptor.get_instance(stream_descriptor)
+        IngestTracingAttributes.set_ingest_descriptor_attributes(stream_descriptor, ingestion_properties)
+
         super().ingest_from_stream(stream_descriptor, ingestion_properties)
 
         return self._ingest_from_stream_with_client_request_id(stream_descriptor, ingestion_properties, None)
